@@ -17,6 +17,7 @@ import (
 
 	"gitlab.com/gitlab-org/cli/cmd/gen-docs/urlwrapper"
 	"gitlab.com/gitlab-org/cli/internal/api"
+	"gitlab.com/gitlab-org/cli/internal/cmdutils"
 	"gitlab.com/gitlab-org/cli/internal/commands"
 	"gitlab.com/gitlab-org/cli/internal/config"
 	"gitlab.com/gitlab-org/cli/internal/glinstance"
@@ -233,7 +234,7 @@ func fatal(err error) {
 }
 
 // adapted from: github.com/spf13/cobra/blob/main/doc/md_docs.go
-// GenMarkdownTreeCustom is the the same as GenMarkdownTree, but
+// GenMarkdownTreeCustom is the same as GenMarkdownTree, but
 // with custom filePrepender and linkHandler.
 func GenMarkdownTreeCustom(cmd *cobra.Command, dir string) error {
 	for _, c := range cmd.Commands() {
@@ -394,8 +395,7 @@ func GenRootMarkdownCustom(cmd *cobra.Command, w io.Writer) error {
 		buf.WriteString("|----------|-------------|\n")
 
 		// Parse the environment variables from the annotation
-		envLines := strings.Split(strings.TrimSpace(envHelp), "\n\n")
-		for _, envBlock := range envLines {
+		for envBlock := range strings.SplitSeq(strings.TrimSpace(envHelp), "\n\n") {
 			lines := strings.Split(envBlock, "\n")
 			if len(lines) > 0 {
 				firstLine := strings.TrimSpace(lines[0])
@@ -483,3 +483,7 @@ func (f *factory) DefaultHostname() string {
 func (f *factory) BuildInfo() api.BuildInfo {
 	return api.BuildInfo{}
 }
+
+func (f *factory) Executor() cmdutils.Executor {
+	return nil
+}
