@@ -1,11 +1,13 @@
 package cmdutils
 
 import (
+	"context"
 	"fmt"
 	"strings"
 	"sync"
 
 	gitlab "gitlab.com/gitlab-org/api/client-go"
+
 	"gitlab.com/gitlab-org/cli/internal/api"
 	"gitlab.com/gitlab-org/cli/internal/config"
 	"gitlab.com/gitlab-org/cli/internal/dbg"
@@ -32,6 +34,7 @@ type Factory interface {
 	IO() *iostreams.IOStreams
 	DefaultHostname() string
 	BuildInfo() api.BuildInfo
+	Executor() Executor
 }
 
 type DefaultFactory struct {
@@ -146,7 +149,7 @@ func (f *DefaultFactory) BaseRepo() (glrepo.Interface, error) {
 		return cachedBaseRepo, nil
 	}
 
-	baseRepo, err := f.resolveBaseRepoFromRemotes()
+	baseRepo, err := f.resolveBaseRepoFromRemotes(context.Background())
 	if err != nil {
 		return nil, err
 	}
@@ -156,7 +159,7 @@ func (f *DefaultFactory) BaseRepo() (glrepo.Interface, error) {
 	return f.cachedBaseRepo, nil
 }
 
-func (f *DefaultFactory) resolveBaseRepoFromRemotes() (glrepo.Interface, error) {
+func (f *DefaultFactory) resolveBaseRepoFromRemotes(ctx context.Context) (glrepo.Interface, error) {
 	remotes, err := f.Remotes()
 	if err != nil {
 		return nil, err
@@ -176,7 +179,7 @@ func (f *DefaultFactory) resolveBaseRepoFromRemotes() (glrepo.Interface, error)
 		return nil, err
 	}
 
-	baseRepo, err := repoContext.BaseRepo(f.io)
+	baseRepo, err := repoContext.BaseRepo(ctx, f.io)
 	if err != nil {
 		return nil, err
 	}
@@ -217,3 +220,9 @@ func (f *DefaultFactory) IO() *iostreams.IOStreams {
 func (f *DefaultFactory) BuildInfo() api.BuildInfo {
 	return f.buildInfo
 }
+
+func (f *DefaultFactory) Executor() Executor {
+	return &factoryExecutor{
+		io: f.io,
+	}
+}
