@@ -583,8 +583,8 @@ func hostnameValidator(v any) error {
 
 func getAccessTokenTip(hostname string) string {
 	return fmt.Sprintf(`
-	Tip: generate a personal access token at https://%s/-/user_settings/personal_access_tokens?scopes=api,write_repository.
-	The minimum required scopes are 'api' and 'write_repository'.`, hostname)
+	The minimum required scopes are 'api' and 'write_repository'.
+	Generate a personal access token at https://%s/-/user_settings/personal_access_tokens?scopes=api,write_repository`, hostname)
 }
 
 func showTokenPrompt(ctx context.Context, io *iostreams.IOStreams, hostname string) (string, error) {
