@@ -40,7 +40,7 @@ func NewCmdDelete(f cmdutils.Factory) *cobra.Command {
 				return err
 			}
 
-			mrs, repo, err := mrutils.MRsFromArgs(f, args, "any")
+			mrs, repo, err := mrutils.MRsFromArgs(cmd.Context(), f, args, "any")
 			if err != nil {
 				return err
 			}
