@@ -10,6 +10,7 @@ import (
 	"gitlab.com/gitlab-org/cli/internal/cmdutils"
 	aliasCmd "gitlab.com/gitlab-org/cli/internal/commands/alias"
 	apiCmd "gitlab.com/gitlab-org/cli/internal/commands/api"
+	attestationCmd "gitlab.com/gitlab-org/cli/internal/commands/attestation"
 	authCmd "gitlab.com/gitlab-org/cli/internal/commands/auth"
 	changelogCmd "gitlab.com/gitlab-org/cli/internal/commands/changelog"
 	pipelineCmd "gitlab.com/gitlab-org/cli/internal/commands/ci"
@@ -53,7 +54,7 @@ func NewCmdRoot(f cmdutils.Factory) *cobra.Command {
 		SilenceErrors: true,
 		SilenceUsage:  true,
 		Annotations: map[string]string{
-			"help:environment": heredoc.Doc(`
+			"help:environment": heredoc.Docf(`
 			BROWSER: The web browser to use for opening links.
 			Can be set in the config with 'glab config set browser mybrowser'.
 
@@ -66,7 +67,7 @@ func NewCmdRoot(f cmdutils.Factory) *cobra.Command {
 			Defaults to the 'client-id' for GitLab.com.
 
 			GITLAB_HOST or GL_HOST: If GitLab Self-Managed or GitLab Dedicated, specify the URL of the GitLab server.
-			(Example: https://gitlab.example.com) Defaults to https://gitlab.com.
+			(Example: %[1]shttps://gitlab.example.com%[1]s) Defaults to %[1]shttps://gitlab.com%[1]s.
 
 			GITLAB_TOKEN: An authentication token for API requests. Set this variable to
 			avoid prompts to authenticate. Overrides any previously-stored credentials.
@@ -96,7 +97,18 @@ func NewCmdRoot(f cmdutils.Factory) *cobra.Command {
 
 			VISUAL, EDITOR (in order of precedence): The editor tool to use for authoring text.
 			Can be set in the config with 'glab config set editor vim'.
-		`),
+
+			GLAB_ENABLE_CI_AUTOLOGIN [EXPERIMENTAL]: Set to %[1]strue%[1]s to enable auto-login in GitLab CI.
+			CI auto-login detects if glab is running in a GitLab CI job by checking the predefined
+			CI/CD variable %[1]sGITLAB_CI%[1]s. 
+			If detected, it uses predefined CI/CD variables like %[1]sCI_SERVER_FQDN%[1]s and %[1]sCI_JOB_TOKEN%[1]s
+			to log in, and ignores other variables like %[1]sGITLAB_HOST%[1]s or %[1]sGITLAB_TOKEN%[1]s.
+			Only glab commands that support %[1]sCI_JOB_TOKEN%[1]s are available.
+			For a list of supported commands, see the CI/CD job token documentation:
+			https://docs.gitlab.com/ci/jobs/ci_job_token/#job-token-access.
+			This flag is experimental. Use with caution and leave feedback in issue 8071:
+			https://gitlab.com/gitlab-org/cli/-/work_items/8071.
+		`, "`"),
 			"help:feedback": heredoc.Docf(`
 			Encountered a bug or want to suggest a feature?
 			Open an issue using '%s'
@@ -147,6 +159,7 @@ func NewCmdRoot(f cmdutils.Factory) *cobra.Command {
 	rootCmd.AddCommand(milestoneCmd.NewCmdMilestone(f))
 	rootCmd.AddCommand(mrCmd.NewCmdMR(f))
 	rootCmd.AddCommand(opentofuCmd.NewCmd(f))
+	rootCmd.AddCommand(attestationCmd.NewCmdAttestation(f))
 	rootCmd.AddCommand(pipelineCmd.NewCmdCI(f))
 	rootCmd.AddCommand(projectCmd.NewCmdRepo(f))
 	rootCmd.AddCommand(releaseCmd.NewCmdRelease(f))
